#!/usr/bin/env python
###########################################################################
# Name: 	         SleepAnalyser
# Description:	 Analyses your movement during your sleep
# Copyright:     George Ruinelli, george@ruinelli.ch
# Last change:  (See file "version")
# Licence:         GPL
###########################################################################


import sys
import random
import time
from time import strftime
import math
import array
import string

from PyQt4.QtCore import * 
from PyQt4.QtGui import * 

import ConfigParser
import os, os.path



import data #own data
from myFunctions import * #Own functions
from myFunctions2 import * #Own functions

#GUIs
from Ui_StartWindow import *
from Ui_RecordWindow import *
from Ui_ViewWindow import *
from Ui_ConfigWindow import *




  
###########################################################################
# Main function
###########################################################################
def main():
    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow
    global config
    global RecordWindowGraph
   
    try:
        if(sys.argv[1]=="debug"): 
            print "Enable Debug mode"
            data.debug=1
    except:
        data.debug=0

    #if not on the N900, a acceleration sensor has to be simulated
    if(os.path.exists("/sys/class/i2c-adapter/i2c-3/3-001d/coord")): data.demo=0	#runs on real N900 hardware
    else: data.demo=1	#runs on other hardware/OS


    if(data.demo==1):
        print "Runs not on a N900 => Use randomizer for acceleration sensor data"
        data.configfolder=data.devconfigfolder
        data.logfolder=data.devlogfolder
    else: data.logfolder=data.defaultlogfolder

    app = QApplication(sys.argv)
    
    config=LoadConfig()
    
    if(data.Ysize==120): #workaround for wrong defaults
        data.Ysize=121
        data.Yscale=1
        data.trigger=30  
        config.set('main', 'Ysize', str(data.Ysize))      
        config.set('main', 'Yscale', str(data.Yscale))      
        print "changed default parameters for Yscale and Ysize"
    
    
    data.app_path=os.path.dirname(__file__)
    if(data.app_path==""): data.app_path="./"
    else: data.app_path=data.app_path+"/"
    
    StartWindow = frmStartWindow()    
    StartWindow.show()    
    StartWindow.UpdateScreenStart()
    
    # Create subwindows
    RecordWindow = frmRecordWindow(StartWindow)
    ViewWindow = frmViewWindow(StartWindow)
    ConfigWindow = frmConfigWindow(StartWindow)
    
    # Hide SubWindows at first
    RecordWindow.hide()
    ViewWindow.hide()
    ConfigWindow.hide()
    
    
    #get user name for in log files
    if(data.user==""):
        EditUserName()

    sys.exit(app.exec_())




def EditUserName():
    text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
                                                                                             "It will be used in the records file, this makes it easier\n" + \
                                                                                             "when you want to share your sleep pattern with others.", 0,  data.user)
    if(text != ""):
        data.user=text[0]
        config.set('main', 'user', str(data.user))    
    else:
        pass
    print "User name:",  data.user


###########################################################################
#  Gets called every second,
###########################################################################
def TimerLoop():
    global RecordWindowGraph
    
#    Show_passed_time("TimerLoop start")

    r=GetSensorData() #(interval: sampling*sample_smoothing*value_smoothing)
    if(r==1):
        WriteIntoLogFile()
        ProcessData() 
        data.ChangesInGraph=1 #Make sure it only gets refreshed once
        RecordWindowGraph.update() #show RecordWindowGraph    
    
    RecordWindow.UpdateScreen()    
    
#    Show_passed_time("TimerLoop end")

  



###########################################################################
# Starte the measurement
###########################################################################
def StartMeasurement():
    global app
    #init value
    data.sample_index=0
    data.values_total=0
    data.arrDataIndex=0
    
    for i in range(0,  len(data.arrData)): #clear data of old records
        for j in range(0,  5): data.arrData[j][i]=0
    
    if(data.Mode==0):
        interval=data.sampling #normal
        if(data.OfflineMode=="True"): #change to offline mode
            cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
            os.popen(cmd)
        data.Xscale=1 #default zoom level
    else:  
        interval=10 #Fast mode for testing
        data.Xscale=0 #max zoom level
    
    data.run=1
    app.timer_GetData = QtCore.QTimer()
    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
    app.timer_GetData.start(interval) 
   
    data.ChangesInGraph=1 #Make sure it only gets refreshed once    
    RecordWindowGraph.update() #show RecordWindowGraph        
    RecordWindow.UpdateScreen()    
    
    StartLogfile(interval)
        
    
    print "Start timers (Interval:", interval ,"ms)..."
    print "Sampling interval:", interval, "ms"
    print "sample_smoothing:", data.sample_smoothing, "x"
    print "value_smoothing:", data.value_smoothing, "x"
    print "=> log interval:", interval*data.value_smoothing, "ms"
    print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
    

    
    


def StopMeasurement():
    global app
    data.run=0
    print "Stop timers..."
    app.timer_GetData.stop()
    data.run=0
    StopLogfile()       
    
    if(data.Mode==0): #normal mode
        if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
            cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
            os.popen(cmd)
    else: #test mode
        data.test=0 # reset test mode if was active






############################################################################
## Stretch graph to show more details
############################################################################
def Zoom(direction):
    if(direction==+1): #zoom in
        if(data.Xscale==0): return
        ViewWindow.ui.bZoomOut.setEnabled(True)
        data.Xscale=(data.Xscale-1) % data.arrXscaleLen
        ProcessData()
        data.ChangesInGraph=1 #Make sure it only gets refreshed once
    else: # -1, zoom out
        if(data.Xscale==data.arrXscaleLen-1): return
        ViewWindow.ui.bZoomIn.setEnabled(True)
        data.Xscale=(data.Xscale+1) % data.arrXscaleLen
        ProcessData()
        data.ChangesInGraph=1 #Make sure it only gets refreshed once




    
    
###########################################################################
# Raise or lower the trigger in the graph + sleep phases
###########################################################################
def MoveTrigger(direction):
    if(direction==+1): #up
        data.trigger=data.trigger+1
        if(data.trigger>data.maxtrigger): data.trigger=data.maxtrigger      
        ProcessData()
        data.ChangesInGraph=1 #Make sure it only gets refreshed once
    else: #-1, down
        data.trigger=data.trigger-1
        if(data.trigger<0): data.trigger=0
        ProcessData()
        data.ChangesInGraph=1 #Make sure it only gets refreshed once

















###########################################################################
#  Class for Main Window
###########################################################################
class frmStartWindow(QMainWindow):
    def __init__(self):
        QMainWindow.__init__(self)
        # This attribute makes the whole Stacked Window thing work
        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
        self.ui = Ui_StartWindow()
        self.ui.setupUi(self)

        QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
        QtCore.QObject.connect(self.ui.bConfig, QtCore.SIGNAL("clicked()"), self.ShowConfigWindow)
        
        file = open(data.app_path+"Info.htm", 'r')
        txt=""
        for line in file: txt=txt+line+"\n"
        file.close()
        self.ui.textBrowser.setHtml(txt)
        
        if(data.app_path!="./"): #only needed if not started in app path
            self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"SleepAnalyser.png"))
            self.ui.bQuick.setIcon(QIcon(data.app_path+"krec.png"))
            self.ui.bCollecting.setIcon(QIcon(data.app_path+"krec.png"))
            self.ui.bLog.setIcon(QIcon(data.app_path+"zoom.png"))
            self.ui.bConfig.setIcon(QIcon(data.app_path+"configure.png"))



    ###########################################################################
    # Show the collectring window (hera the data gets visualised during the logging)
    ###########################################################################
    def StartMeasurementNormal(self):
        data.Mode=0 #run in normal mode
        data.test=0 #show axis lables        
        self.StartMeasurement()
        
        
    ###########################################################################
    # Show the collectring window (hera the data gets visualised during the logging)
    ###########################################################################
    def StartMeasurementQuick(self):
        data.Mode=1 #run in quick mode (for testing only)
        data.Xscale=0 #default zoom level
        data.test=1 #hide axis lables
        self.StartMeasurement()
        
        
    def StartMeasurement(self):
        global RecordWindowGraph
        RecordWindow.show()
#        StartWindow.hide()
        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
        StartMeasurement()
        RecordWindow.UpdateScreenStart()
        RecordWindowGraph.show()
        
        
    ###########################################################################
    # Show the log window (her ethe data from a file gets visualised)
    ###########################################################################
    def ShowViewWindow(self):
        global ViewWindowGraph
        
        #reset to default log folder
        if(data.demo==1): data.logfolder=data.devlogfolder #folder on devel PC
        else: data.logfolder=data.defaultlogfolder
        if os.path.exists(data.logfolder+data.lastlogfile):
            data.logfilename=data.lastlogfile
        else:
            LoadFileList()
            l=len(data.arrLogFiles)
            if(l>0):
                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
            else: #no logfiles in logfolder, show "open file" dialog
                tmp=ViewWindow.ShowFileDialog()
                if(not os.path.exists(tmp)): #only continue if valid log file selected
                    StartWindow.show()
                    ViewWindow.hide()
                    return #only continue if valid log file selected
                tmp2=tmp.split("/")
                l=len(tmp2)    
#                if(tmp2[l-1]==""): #no file selected
#                    print "filename=empty"
#                    return
                data.logfilename=tmp2[l-1]
                data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
                print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
#                data.logfilename=x
        
#        print data.logfilename
        
        ViewWindowGraph = ViewWindowCanvas(self)
        ViewWindow.ShowLogFile()
        
        if(data.logfilename!=""):
            print "ViewWindow.show()"
            ViewWindow.show()
        else:
            "No valid file selected"
#        StartWindow.hide()
        
        
        
    def ShowConfigWindow(self):
        ConfigWindow.UpdateScreen()
        ConfigWindow.show()
#        StartWindow.hide()




    def UpdateScreenStart(self):
        try:   
            print "Application path:",  data.app_path
            file = open(data.app_path+"version", 'r')
            data.version = file.readline()
            data.version=data.version[:-1]
            data.build = file.readline()
        except:
            print "Version file not found"
        self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))

    def closeEvent(self, event):
        global config
        WriteConfig(config)

















###########################################################################
#  Class for Collecting Window
###########################################################################
class frmRecordWindow(QMainWindow):
    def __init__(self, parent=None):
#        QMainWindow.__init__(self, parent)
        # Notice that you must give a parent window as parameter to the constuctor
        QMainWindow.__init__(self, parent)
        # Also set the Stacked Window parameter for every subwindow in the stack
        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
        
        self.ui = Ui_RecordWindow()
        self.ui.setupUi(self)
        
        QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), self.ToggleMeasurement)
        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
        
        if(data.app_path!="./"): #only needed if not started in app path
            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
            

    def UpdateScreen(self):
        if(data.demo==0):
            self.ui.lblSamples_Taken.setText(str(data.values_total))
        else:
            self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Demo Mode)")

        t=time.mktime(time.localtime())
        time_difference=t-data.StartTimeSec
        t=strftime("%H:%M:%S", time.gmtime(time_difference))
        self.ui.lblElapsedTime.setText(t)
#        self.ui.lblTrigger.setText(str(data.trigger))
        
        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
        else: self.ui.bZoomIn.setEnabled(True)
        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
        else: self.ui.bZoomOut.setEnabled(True)

        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
        else: self.ui.bRaiseTrigger.setEnabled(True)
        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
        else: self.ui.bLowerTrigger.setEnabled(True)
            

    def UpdateScreenStart(self):
        self.ui.lblLogfile.setText(str(data.logfilename))
        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
        self.ui.lblStarttime.setText(t)
        self.ui.lblSamples_Taken.setText("0")
        self.ui.lblElapsedTime.setText("00:00:00")
#        self.ui.lblYscale.setText(str(data.Yscale))
#        self.ui.lblTrigger.setText(str(data.trigger))
        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
        self.ui.bStop.setIcon(QIcon(data.app_path+"krec2.png"))
        self.ui.bStop.setText("Stop recording")

        self.UpdateScreen()
        
        
    def UpdateScreenStop(self):
        self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
        self.ui.bStop.setIcon(QIcon(data.app_path+"krec.png"))
        self.ui.bStop.setText("Start recording")
        
        
    def ToggleMeasurement(self):
        global app
        if(data.run==0): #not running
            StartMeasurement()
            self.UpdateScreenStart()
        else: #running
            StopMeasurement()
            self.askdumprecord()  
            self.UpdateScreenStop()
            data.test=0 # reset test mode if was active
        
        
        
    def ZoomIn(self):
        Zoom(+1)
#        self.ui.bZoomOut.setEnabled(True)
#        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
#        else: self.ui.bZoomIn.setEnabled(True)
        self.update()
        self.UpdateScreen()

    def ZoomOut(self):
        r=Zoom(-1)
#        self.ui.bZoomIn.setEnabled(True)
#        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
#        else: self.ui.bZoomOut.setEnabled(True)
        self.update()
        self.UpdateScreen()


    def RaiseTrigger(self):   
        MoveTrigger(+1)
        self.ui.bLowerTrigger.setEnabled(True)
        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
        else: self.ui.bRaiseTrigger.setEnabled(True)
        self.update() 
        self.UpdateScreen()
        
    def LowerTrigger(self):     
        MoveTrigger(-1)
        self.ui.bRaiseTrigger.setEnabled(True)
        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
        else: self.ui.bLowerTrigger.setEnabled(True)
        self.update()
        self.UpdateScreen()


    def closeEvent(self, event):
        #in case measurement is still running (user did not click on "stop")
        if(data.run==1): 
            StopMeasurement()
            self.askdumprecord()            
        StartWindow.show()
        self.close() 


    def askdumprecord(self):
    #check if user wants to keep this record
        reply = QtGui.QMessageBox.question(self, 'Keep this Record?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
        if reply == QtGui.QMessageBox.No:
            print "Delete logfile: "+data.logfilename
            os.remove(data.logfolder+data.logfilename)
        else:
            data.lastlogfile=data.logfilename
#            print "lastlogfile:",  data.lastlogfile
            config.set('main', 'lastlogfile', str(data.lastlogfile))   
















###########################################################################
# Class for Log Window
###########################################################################
class frmViewWindow(QMainWindow):
    def __init__(self, parent=None):
#        QMainWindow.__init__(self, parent)
        # Notice that you must give a parent window as parameter to the constuctor
        QMainWindow.__init__(self, parent)
        # Also set the Stacked Window parameter for every subwindow in the stack
        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
        
        
        self.ui = Ui_ViewWindow()
        self.ui.setupUi(self)
        
        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
        QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextLogFile)
        QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastLogFile)
        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
        QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
        QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
        QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
        QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
        
        self.ui.bLeft.hide() #not yet used
        self.ui.bRight.hide() #not yet used
        
        if(data.app_path!="./"): #only needed if not started in app path
            self.ui.bLast.setIcon(QIcon(data.app_path+"arrow-left-double.png"))
            self.ui.bNext.setIcon(QIcon(data.app_path+"arrow-right-double.png"))
            self.ui.bDelete.setIcon(QIcon(data.app_path+"edittrash.png"))
            self.ui.bOpen.setIcon(QIcon(data.app_path+"document-open-folder.png"))
            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
            self.ui.bLeft.setIcon(QIcon(data.app_path+"go-previous.png"))
            self.ui.bRight.setIcon(QIcon(data.app_path+"go-next.png"))
            
#        self.ui.lblYscale.setText(str(data.Yscale))


    def UpdateScreen(self):
        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
        shortfolder=string.replace(data.logfolder, "//", "/") #workaround
        self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
#        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
#        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
#        self.ui.lblTrigger.setText(str(data.trigger))
#        self.ui.lblYscale.setText(str(data.Yscale))
        
        try:
            start=str(data.StartDate)+" "+str(data.arrData[0][0])
            stop=str(data.arrData[0][data.arrDataIndex-1])
            t0=time.strptime(start, "%d-%m-%Y %H:%M:%S")
            t1=time.strptime("01-01-2000 "+stop, "%d-%m-%Y %H:%M:%S")
            tt0=time.mktime(t0)
            tt1=time.mktime(t1)
            dt=strftime("%H:%M:%S", time.gmtime(tt1-tt0))
            day=strftime("%A", time.gmtime(tt0))
        except:
            dt=""
            day=""            
        self.ui.lblTimes.setText("Start: "+str(day)+" "+str(data.arrData[0][0])+"   End: "+str(data.arrData[0][data.arrDataIndex-1])+"   Duration: "+str(dt))
        self.ui.lblNote.setText(str(data.Note))

        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
        else: self.ui.bZoomIn.setEnabled(True)
        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
        else: self.ui.bZoomOut.setEnabled(True)

        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
        else: self.ui.bRaiseTrigger.setEnabled(True)
        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
        else: self.ui.bLowerTrigger.setEnabled(True)
        
        print len(data.arrLogFiles),  (data.arrLogFiles)
        if(len(data.arrLogFiles)<2): #disable last/next buttons if only one file in folder
            self.ui.bNext.setEnabled(False)
            self.ui.bLast.setEnabled(False)
        else:
            self.ui.bNext.setEnabled(True)
            self.ui.bLast.setEnabled(True)



    def ShowLogFile(self):
        r=OpenLogFile()    
        if(r==1): #file too long            
            QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
        elif(r==2): #file does not exist
#            closeEvent(0)
            self.OpenRecord()
            return
        LoadFileList()
        ProcessData()
        data.Xscale=1 #default zoom level
        data.ChangesInGraph=1 #Make sure it only gets refreshed once
        ViewWindowGraph = ViewWindowCanvas(self)
        ViewWindowGraph.show()
        self.UpdateScreen()
        
        
    def NextLogFile(self):
        data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
        data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
        self.ShowLogFile()


    def LastLogFile(self):
        data.arrLogFileIndex=(data.arrLogFileIndex-1)  % len(data.arrLogFiles)
        data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
        self.ShowLogFile()


        
    def ZoomIn(self):
        Zoom(+1)
        self.ui.bZoomOut.setEnabled(True)
        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
        else: self.ui.bZoomIn.setEnabled(True)
        self.update()

    def ZoomOut(self):
        r=Zoom(-1)
        self.ui.bZoomIn.setEnabled(True)
        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
        else: self.ui.bZoomOut.setEnabled(True)
        self.update()
        
        

    def RaiseTrigger(self):   
        MoveTrigger(+1)
        self.update() 
        self.UpdateScreen()
        
    def LowerTrigger(self):     
        MoveTrigger(-1)
        self.update()
        self.UpdateScreen()
        
        
    def goLeft(self):
        pass
        
    def goRight(self):
        pass
        

    def DeleteLogFile(self):
        reply = QtGui.QMessageBox.question(self, 'Delete Record?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
        if reply == QtGui.QMessageBox.Yes:
            print "Delete logfile: "+data.logfilename
            os.remove(data.logfolder+data.logfilename)    
            
            LoadFileList()
            l=len(data.arrLogFiles)
            if(l>0):
                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
            else: #no logfiles in logfolder, show "open file" dialog
                tmp=self.ShowFileDialog()
                if(tmp==""): #only continue if valid log file selected
                    self.closeEvent("") #no file selected, close
                    return
                tmp2=tmp.split("/")
                l=len(tmp2)    
                data.logfilename=tmp2[l-1]
                data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
                print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
            self.ShowLogFile()
            self.UpdateScreen()



    def OpenRecord(self):
        tmp=self.ShowFileDialog()
        if(not os.path.exists(tmp)): #only continue if valid log file selected
            print "OpenRecord: File does not exist"
#            ViewWindow.hide()
#            StartWindow.show()
            return 
        print "OpenRecord: File ok"
        tmp2=tmp.split("/")
        l=len(tmp2)    
        data.logfilename=tmp2[l-1]
        data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
        print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
        self.ShowLogFile()
    
    
    
    
    def ShowFileDialog(self):        
        data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
        print "Open file dialog in:",  data.logfolder
        tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
        print "Selected file:",  tmp
#        tmp2=tmp.split("/")
#        l=len(tmp2)    
#        x=tmp2[l-1]
#        return x
        return tmp


    def closeEvent(self, event):
        config.set('main', 'trigger', str(data.trigger))      
        ViewWindow.close()
        StartWindow.show()

    def EditNote(self):
        r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:",  QLineEdit.Normal,  data.Note)
        if(r[1]==True): #OK pressed
            data.Note=str(r[0])
            self.ui.lblNote.setText(str(data.Note))
            ChangeNoteInFile() #rewrite log file















###########################################################################
# Class for Configuration Window
###########################################################################
class frmConfigWindow(QMainWindow):
    def __init__(self, parent):
        # Notice that you must give a parent window as parameter to the constuctor
        QMainWindow.__init__(self, parent)
        # Also set the Stacked Window parameter for every subwindow in the stack
        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
        
        self.ui = Ui_ConfigWindow()
        self.ui.setupUi(self)
        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
              
        QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
        
        

    def UpdateScreen(self):
        if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
        else: self.ui.cOfflineMode.setChecked(False)        
        self.ui.lblUserName.setText(str(data.user))


    def closeEvent(self, event):        
        if(self.ui.cOfflineMode.isChecked()==True):          
                data.OfflineMode="True"
        else: 
            data.OfflineMode="False"
        config.set('main', 'OfflineMode', str(data.OfflineMode))   
        config.set('main', 'user', str(data.user))      
        
        ConfigWindow.close()
        StartWindow.show()


    def EditUserName(self):
        EditUserName()
        self.ui.lblUserName.setText(str(data.user))








###########################################################################
# Class for drawing the RecordWindowGraph
###########################################################################
class RecordWindowCanvas(QtGui.QWidget):
    def __init__(self, parent):
        QMainWindow.__init__(self, parent)    
        self.setGeometry(9, 180, 782, data.Ysize+55)
    
    def paintEvent(self, event):
        showGraph(self,  QtGui)



    
###########################################################################
# Class for drawing the ViewWindowGraph
###########################################################################
class ViewWindowCanvas(QtGui.QWidget):
    def __init__(self, parent):
        QMainWindow.__init__(self, parent)    
        self.setGeometry(9, 100, 782, data.Ysize+55)
    
    def paintEvent(self, event):
        showGraph(self,  QtGui)
    
    
    
###########################################################################
# Now we can start it.
main()

